@@ -20,3 +20,14 @@ iso.lang(lang.aff("Circassian"))
 ## -----------------------------------------------------------------------------
 aff.lang("Adyge")
 
+## -----------------------------------------------------------------------------
+subc.lang("Lechitic")
+
+## -----------------------------------------------------------------------------
+library(ape)
+plot(read.tree(text = subc.lang("Lechitic")))
+
+## -----------------------------------------------------------------------------
+plot(read.tree(text = subc.lang("Lechitic")),
+     tip.color = c("red", "black", "black", "black"))
+
